@@ -1549,6 +1549,20 @@ mapi_folder_get_message_sync (CamelFolder *folder,
 
 	add_message_to_cache (mapi_folder, uid, &msg, cancellable);
 
+	if (msg) {
+		CamelMessageFlags flags;
+		gboolean has_attachment;
+
+		flags = camel_message_info_get_flags (mi);
+		has_attachment = camel_mime_message_has_attachment (msg);
+		if (((flags & CAMEL_MESSAGE_ATTACHMENTS) && !has_attachment) ||
+		    ((flags & CAMEL_MESSAGE_ATTACHMENTS) == 0 && has_attachment)) {
+			camel_message_info_set_flags (
+				mi, CAMEL_MESSAGE_ATTACHMENTS,
+				has_attachment ? CAMEL_MESSAGE_ATTACHMENTS : 0);
+		}
+	}
+
 	g_clear_object (&mi);
 
 	return msg;
